var toolbox       = require( 'compose-toolbox' )
var Event         = toolbox.event
var notify        = require( '../modules/notify' )


// Handle submit behaviors:
//  - disable button on submit
//  - submit messages
//
Event.on( document, 'submit', function(event) {

  // Send form messages
  // Look for an element with the data-submit-message or use the form itself
  var message = ( event.target.querySelector('[data-submit-message]') || event.target ).dataset.submitMessage
  if ( message ) notify( 'form-action', message )

  var button = event.target.querySelector('[type=submit]')
  if ( button.dataset.disableOnSubmit == 'false' ) return

  if (!button.dataset.disableWith) button.dataset.disableOnSubmit = true
  button.disabled = true

  // Look for elements with disable-with text and replace the text
  var elements = event.target.querySelectorAll('[data-disable-with]')

  toolbox.each( elements, function( el ) {
    var buttonText = el.querySelector('.button-text') || el

    el.dataset.enabledText = buttonText.innerHTML
    buttonText.innerHTML = el.dataset.disableWith
  })


  event.preventDefault()
  event.stopImmediatePropagation()

  // This allows the submit functions to occur
  toolbox.event.delay( function() {
    document.body.classList.add('modal')
  })

  if ( document.body.dataset.fakeSubmit ) {
    var ev = new CustomEvent('fake-submit', { bubbles: true, cancelable: true })
    event.target.dispatchEvent( ev ) 
  } else {
    event.target.submit()
  }

})

// When a back button is used:
//  - Disabled buttons remain disabled
//  - Progress notifications remain active
//
// This renables buttons and hides notifications.
window.onpageshow = function(event) {

  document.body.classList.remove('modal')
  
  var button = document.querySelector('[data-disable-with][disabled],[data-disable-on-submit][disabled]')
  if ( button ) button.disabled = false

  if ( button && button.dataset.enabledText ) {
    var buttonText = button.querySelector('.button-text') || button
    buttonText.innerHTML = button.dataset.enabledText
  }

  // Dismiss leftover progress notifications
  if ( document.querySelector( '.notification.form-action' ) ) {
    notify.remove()
  }
}
