var toolbox = require( 'compose-toolbox' ),
    Event = toolbox.event,
    esvg  = require( '../_esvg' ),

    defaultsByType = {
      success: { dismissAfter: 3500 },
    },

    iconsByType = {
      message:        "message-circle",
      error:          "no-circle",
      progress:       "progress-circle",
      'form-action':  "progress-circle",
      success:        "thumbs-up-circle",
    },

    autoDismissTimeout,
    messageEl,

    template = '\
<div class="notification">\
  <div class="notification-content">\
    <div class="notification-message" role="alert"></div>\
    <button class="notification-close" href="#" role="button" aria-label="close message">\
    </button>\
  </div>\
</div>\
'

function notify (type, message, options) {

  if ( !options && typeof message == 'object' ) {
    options = message
    message = type
    type = 'message'
  }

  if ( !message ) {
    message = type
    type = 'message'
  }

  return show( type, message, toolbox.merge( defaultsByType[type], options || {} ) )
}

function show ( type, message, options ) {

  clearTimeout( autoDismissTimeout )
  if ( messageEl ) return dismiss( function(){ show( type, message, options ) })

  document.body.insertAdjacentHTML( 'beforeend', template )
  messageEl     = document.body.lastChild
  var typeIcon  = esvg.use( iconsByType[type] || type )
  var closeIcon = esvg.use( 'x-circle', { 'scale': true, 'class': 'close-icon' } )

  var msg = messageEl.querySelector( '.notification-message' )
  msg.innerHTML = message

  if ( typeIcon ) msg.insertAdjacentHTML( 'beforebegin', "<span class='notification-type-icon'>" + typeIcon.outerHTML + "</span>" )
  if ( closeIcon ) messageEl.querySelector( '.notification-close' ).innerHTML = closeIcon.outerHTML

  if ( type ) {

    messageEl.classList.add( type )

    if ( options && options.dismissAfter ){
      autoDismissTimeout = window.setTimeout( dismiss, options.dismissAfter )
    }
  }

  messageEl = document.body.lastChild

  Event.keyOne( 'esc', dismiss )
  Event.one( messageEl, 'click', '.notification-close', dismiss )

  return {
    dismiss: dismiss
  }
}

function dismiss ( callback ) {

  if ( document.querySelector('.notification') == null ) { return }

  clearTimeout( autoDismissTimeout )

  var cb

  if ( typeof callback == 'function' ) {
    cb = function() { remove(); callback() }
  } else {
    cb = remove;
  }

  var timeout = window.setTimeout( cb, 500 )

  Event.one( messageEl, 'animationstart', function() {
    clearTimeout( timeout )

    Event.afterAnimation( messageEl, cb )
  })

  messageEl.classList.add( 'dismiss' )
}

function remove () {
  messageEl = document.querySelector('body > .notification')

  if (messageEl) {
    messageEl.parentNode.removeChild( messageEl )
  }
  messageEl = null
}

notify.dismiss = dismiss
notify.remove = remove

module.exports = notify
