module Tungsten
  module ButtonHelper
    def button(text = nil, options = nil, &block)
      if text.is_a?(Hash) || block_given? && options.nil?
        options = text 
        text = nil
      end
      options ||= {}
      tag_name = options[:href].present? ? :a : :button

      options[:class] = button_classes(options)

      options[:data] = {
        toggle: options.delete(:toggle),
        remote: options.delete(:remote),
        'toggle-class' => options.delete(:toggle_class),
        'submit-message' => options.delete(:submit_message),
        'disable-on-submit' => options.delete(:disable_on_submit),
        'disable-with' => options.delete(:disable_with),
      }.merge( options[:data] || {} )

      if options[:confirm]
        options[:dialog] ||= {}
        options[:dialog][:confirm] = options.delete(:confirm)
      end

      if options[:confirm_if]
        options[:dialog][:if] = options.delete(:confirm_if)
      end

      (options.delete(:dialog) || {}).each do |key, val|
        if key.to_s == 'confirm'
          options[:data]["dialog-title"] ||= val
          options[:data]["dialog-confirm"] = true
        else
          options[:data]["dialog-#{key}"] = val
        end
      end

      options[:type] = 'submit' if options[:to]

      if tooltip = options.delete(:tooltip)
        options[:aria_label] ||= tooltip
        options[:class] << ' has-tooltip'
      end

      button_options = {
        role: 'button',
        id: options.delete(:id),
        data: options.delete(:data),
        class: options.delete(:class),
        disabled: options.delete(:disabled),
        type: options.delete(:type) || 'button',
        target: options.delete(:target),
        href: options.delete(:href),
        'aria-label'=> options.delete(:aria_label),
        tabindex: options.delete(:tabindex)
      }

      button = content_tag tag_name, button_options do
        if options[:icon]
          concat content_tag(:span, class: 'inline-icon') {
            use_svg(options.delete(:icon), height: '1em', fill: 'currentColor', desc: options.delete(:desc))
          }
        end
        concat content_tag(:span, class: 'button-text') { text } if text
        concat capture(&block).html_safe if block_given?
      end

      content_tag(:span, class: 'button-wrapper') {
        if options[:to]
          options[:data] = {}
        
          form = button_to 'input', options.delete(:to), options
          form.sub(/<input type="submit".+?>/, button).html_safe
        else
          button
        end
      }
    end

    def primary_button(text = nil, options = nil, &block)
      if text.is_a?(Hash)
        options = text 
        text = nil
      end
      options ||= {}
      options[:class] = button_classes(options, 'primary')
      options[:type] = 'submit'
      button(text, options, &block)
    end

    def destructive_button(text = nil, options = nil, &block)
      if text.is_a?(Hash)
        options = text 
        text = nil
      end
      options ||= {}
      options[:class] = button_classes(options, 'destructive')
      options[:method] = 'delete'
      button(text, options, &block)
    end

    def destructive_primary_button(text = nil, options = nil, &block)
      if text.is_a?(Hash)
        options = text 
        text = nil
      end
      options ||= {}
      options[:class] = button_classes(options, 'primary-destructive')
      options[:type] = 'submit'
      options[:method] = 'delete'
      button(text, options, &block)
    end

    def copy_button(target, text=nil, options={}, &block)

      if text.is_a? Hash
        options = text
        text = nil
      end

      options[:tooltip] ||= "Copy to clipboard"
      options[:class] = button_classes(options, 'copy-button')

      options[:data] ||= {}
      options[:data][:copy_target] = target

      if text.nil?
        icon_button( 'copy', options, &block )
      else
        options[:icon] = 'copy' if options[:icon].nil?
        button( text, options, &block )
      end
    end

    def icon_button(icon, options={})
      options[:class] = button_classes(options, 'icon-button')

      icon_options = {
        title: options.delete(:title),
        width: options.delete(:width),
        height: options.delete(:height),
        color: options.delete(:color),
        fill: options.delete(:fill),
        'fill-opacity' => options.delete(:fill_opacity),
        stroke: options.delete(:stroke),
        desc: options.delete(:desc)
      }

      icon_options[:scale] = true unless icon_options[:width] || icon_options[:height]

      button( options ) do
        concat content_tag(:span, class: 'inline-icon') {
          use_svg icon, icon_options
        }
      end
    end

    def destructive_icon_button(icon, options={})
      options[:class] = button_classes(options, 'destructive')
      icon_button(icon, options)
    end

    def destructive_primary_icon_button(icon, options={})
      options[:class] = button_classes(options, 'primary-destructive')
      icon_button(icon, options)
    end

    def primary_icon_button(icon, options={})
      options[:class] = button_classes(options, 'primary')
      icon_button(icon, options)
    end

    def button_classes(options, more=nil)
      classes = ['button']
      classes << more
      classes << options[:class]
      classes << options.delete(:size)
      classes << 'clear' if options.delete(:clear)
      classes.flatten.compact.join(' ').split(' ').uniq.join(' ').strip
    end

  end
end
