module Tungsten
  module CardHelper
    class Card < Tungsten::Helper

      def initialize( title = nil, options = {} )
        if title && title.is_a?(Hash)
          @options = title
          @title = nil
        else
          @options = options
          @title = title
        end
        @options[:data] ||= {}
        @options[:data][:animate] ||= @options.delete(:animate)
        @options[:class] = "card-section #{@options.delete(:class)} #{"hidden" if @options.delete(:hidden)}".strip
      end

      def display( body )
        content_tag( :section, @options ) do
          content_tag( :div, class: 'card-wrapper toggle-drawer' ) {
            content_tag( :div, class: 'card' ) {
              concat header( @title ) if @title
              if first_header = body.scan(/\A<header.+?header>/m).first
                concat first_header.html_safe
                body = body.sub(first_header, '').html_safe
              end
              concat content_tag(:div, class: 'card-content') { body }
            }
          }
        end
      end

      def header( text = nil, options = {}, &block )
        if text.is_a? Hash
          options = text
          text = nil
        end

        options[:class] = "card-header #{options[:class]}".strip

        content_tag( :header, options ) {
          concat content_tag( :h2, text, class: 'card-heading' ) if text
          concat capture(&block).html_safe if block_given?
        }
      end

      def footer( text = nil, options = {}, &block )
        if text.is_a? Hash
          options = text
          text = nil
        end

        options[:class] = "card-footer #{options[:class]}".strip

        content_tag( :footer, options ) {
          concat content_tag( :p, text ) unless text.nil?
          concat capture(&block).html_safe if block_given?
        }
      end

      def description( text = nil, options = {}, &block )
        if text.is_a? Hash
          options = text
          text = nil
        end

        options[:class] = "card-description #{options[:class]}".strip

        content_tag( :p, options ) {
          concat text unless text.nil?
          concat capture(&block).html_safe if block_given?
        }
      end

      def actions( options={}, &block )
        options[:class] = "card-actions #{options[:class]}".strip

        content_tag( :nav, options, &block )
      end

      def well( options={}, &block )
        options[:class] = "card-well #{options[:class]}".strip

        content_tag( :div, options, &block )
      end

      def divider( options={} )
        options[:class] = "card-divider #{options[:class]}".strip

        tag.span(options)

      end

    end
  end
end
