module Tungsten
  module ContentHelper

    # Set custom favicon
    def favicon(&block)
      content_for :favicon, &block
    end

    # Set custom logo
    def logo(&block)
      content_for :logo, &block
    end

    # Set custom top navigation
    def top_nav(&block)
      content_for :top_nav, &block
    end

    # Set custom top navigation for app links
    def app_nav(&block)
      content_for :app_nav, &block
    end

    # Blank slate layout
    def footer(&block)
      content_for :footer, &block
    end

    # Set custom page title
    def title(title = nil)
      title ? content_for(:title) { title + " | " + Site.name } : content_for(:title).presence
    end

    # Set custom page meta description
    def description(description = nil)
      description ? content_for(:description) { description } : content_for(:description).presence
    end

    # Set custom page meta keywords
    def keywords(keywords = nil)
      keywords ? content_for(:keywords) { keywords } : content_for(:keywords).presence
    end

    def pin_tab_icon(path, color='black')
      %Q{<link rel="mask-icon" mask href="#{path}" color="#{color}">}.html_safe
    end

    def human_title(input)
      input.to_s.humanize.titlecase
    end

    def toggle_time_tag(date, options={})
      options[:toggle] = true
      options[:class] = 'time-toggle'
      options[:data] ||= {}
      options[:data]['timeago'] = options.delete(:timeago_style) || 'long'
      options[:data][:mode] = options.delete(:start)
      options[:icon] = 'sync-circle'

      content_tag(:span, class: 'time-wrapper') {
        time_tag(date, options)
      }
    end

    def time_ago_tag(date, options={})
      options[:timeago] = true
      options[:class] = 'timeago has-tooltip'
      options[:data] ||= {}
      options[:data]['timeago-style'] = options.delete(:timeago_style) || 'long'
      options['aria-label'] = date.sub('T',' ').sub('+00:00', ' UTC')
      
      time_tag(date, options)
    end

    def parse_date(date)
      DateTime.parse(date.to_s).new_offset(0).iso8601
    end

    def time_tag(date, options={})
      iso_date = parse_date(date)

      options[:datetime] = iso_date

      icon = use_svg(options.delete(:icon)) if options[:icon]
      
      unless options.delete(:toggle) || options.delete(:timeago)
        options[:class] = 'has-tooltip'
        options['aria-label'] = time_ago_in_words(iso_date) + ' ago'
      end

      content_tag(:time, options) {
        concat content_tag(:span, class: 'date-text') {
          ('<span class="date">' + iso_date.sub('T','</span> <span class="time">').sub('+00:00','</span> <span class="timezone">UTC</span>')).html_safe
        }
        concat ' '
        concat icon
      }

    end

    def iso_date_string(date)
      parse_date(date).sub('T', ' ').sub('+00:00', ' UTC')
    end

    def timeago_tag(date, options={})
      date = DateTime.parse(date.to_s).iso8601

      options[:class] = 'timeago'

      options[:data] ||= {}
      options[:data]['timeago-style'] = options.delete(:timeago_style)

      content_tag(:time, options) { date }
    end

    
    def drawer(id, options = {}, &block)
      options[:id] = id
      options[:hidden] = true if options[:hidden].nil?
      options[:data] ||= {}
      options[:data][:animate] ||= options.delete(:animate)
      options[:class] = "#{options[:class]} #{"hidden" if options.delete(:hidden)}".strip
      options.delete(:hidden)

      content_tag(options.delete(:tag) || :div, options, &block )
    end

    def set_aria!( options, aria )
      opts = {}
      aria.each do |key, val|
        opts["aria-#{key}"] = val
      end

      options.merge!(opts)
    end
  end
end
