module Tungsten
  module DeploymentsHelper
    def deployment_data(name = nil)
      deployments = Cyborg.config_data['deployments']['deployments']

      if name.nil?
        deployments
      else
        deployment = deployments.find { |d|
          d[:name] =~ /#{name}/i || d[:slug] == name
        }

        if deployment.nil? && !Rails.env.production?
          raise %Q{No deployment type "#{name}" exists.}
        end

        deployment
      end
    end

    def deployment_graphic
      @deployment_icon ||= Esvg.find_symbol('deployment')
    end

    def deployment_text(text, options={})
      options = {
        x: deployment_graphic.width.to_f / 2,
        y: deployment_graphic.height.to_f / 2, fill: "currentColor",
        "font-weight" => 700,
        "font-size" => "57px",
        "text-anchor" => "middle",
        "dominant-baseline" =>"central",
        "alignment-baseline" => "central"
      }.merge(options)

      content_tag(:text, text, options).html_safe
    end

    def deployment_svg(name, options={})
      data = deployment_data(name)
      (options[:use] ||= {})
      options[:use][:stroke] ||= options.delete(:stroke) || "currentColor"
      options[:use][:stroke_width] ||= options.delete(:stroke_width) || 4
      options[:use][:class] = "deployment-icon-hex #{options[:use][:class]}".strip

      options[:color]   ||= "#fff"
      options[:fill]    ||= "none"
      # options[:fill]    ||= "url(##{data[:name].downcase}-gradient-bg)"
      options[:content] ||= deployment_text(data[:short_name], options.delete(:text) || {})

      deployment_graphic.use(options).html_safe
    end

    def deployment_icon(name, options={})
      options[:stroke_width] ||= 8
      options[:text] ||= { "font-weight" => 600, "font-size" => "76px" }
      deployment_svg name, options
    end
  end
end
