module Tungsten
  module ProgressBarHelper
    def progress_bar(completion, options={}, &block)
      if completion > 1
        raise "Completion must be between 0 and 1, You passed: #{completion}"
      end

      # No need for floats
      completion = (completion*100).to_i

      options[:class] = "progress-bar #{options[:class]}".strip
      
      label = block_given? ? capture(&block) : options.delete(:label)

      description_detail = options.delete(:description_detail)
      description_status = options.delete(:description_status)

      outline_class = "progress-bar-outline #{ 'full-width' if options[:full_width] }".strip
      fill_class = "progress-bar-fill #{options.delete(:color)}".strip
      description_class = "progress-bar-description #{ 'full-width' if options[:full_width] }".strip
      
      set_aria! options, {
        role:      'progressbar',
        valuemin:  0,
        valuemax:  100,
        valuenow:  completion,
        valuetext: strip_tags(label)
      }

      content_tag( :div, class: "progress-bar-wrapper #{ 'with-label' if label } #{ 'with-description' if description_status || description_detail }" ) {
        concat content_tag( :div, class: 'progress-bar-label') {
          concat content_tag( :div, class: 'progress-bar-label-content' ) { label }
        } if label
        concat content_tag( :div, options ) {
          concat content_tag( :div, class: outline_class ) {
            tag.div class: fill_class, style: "width: #{completion}%"
          }
          concat content_tag( :div, class: 'progress-bar-percentage') { "#{completion}%" } if options[:description_status]
          concat content_tag( :div, class: description_class ) { 
            concat content_tag( :div, class: 'progress-bar-description-detail' ) { description_detail }
            concat content_tag( :div, class: 'progress-bar-description-status' ) { description_status }
          } if description_detail || description_status
        }
      }
    end
  end
end
