module Tungsten
  module TableHelper
    def tr_drawer(id, options = {}, &block)

      colspan = options.delete(:colspan) || 100
      options[:class] = "#{options[:class]} table-drawer-content toggle-drawer".strip
      options[:animate] = 'drawer' if options[:animate].nil?

      content_tag(:tr, class: "table-drawer") {
        content_tag(:td, colspan: colspan) {
          drawer(id, { class: "table-drawer-content-wrapper", hidden: options.delete(:hidden), animate: options.delete(:animate) }) {
            content_tag(:div, options, &block)
          }
        }
      }
    end

    class TableDrawer < Tungsten::Helper

      def initialize( options = {} )
        @options = options
        @id = "handle-#{SecureRandom.hex(5)}"
        @drawer_id = "drawer-#{SecureRandom.hex(5)}"
      end

      def display( body )
        options = {
          class: 'table-drawer-handle',
          id: @id,
        }
        options[:data] ||= {}

        options[:data]['toggle-class'] = 'open closed'
        options[:data]['toggle'] = "##{@drawer_id}"
        options[:role] = 'button'
        options[:class] << ' toggle-handle closed'
        content_tag(:tr, options) { body }
      end

      def drawer(options={}, &block)
        options[:animate] = 'drawer'
        tr_drawer(@drawer_id, options, &block)
      end

      def close( &block )
        capture(&block).sub(/>/, " role='button' \
                            data-hide=\"##{@drawer_id}\" \
                            data-remove-class=\"open; ##{@id}\" \
                            data-add-class=\"closed; ##{@id}\">").html_safe
      end

      def toggle( &block )
        capture(&block).sub(/>/, " role='button' \
                            data-toggle=\"##{@drawer_id}\" \
                            data-toggle-class=\"open closed; ##{@id}\">").html_safe
      end

      def open( &block )
        capture(&block).sub(/>/, " role='button' \
                            data-show=\"##{@drawer_id}\" \
                            data-add-class=\"open; ##{@id}\" \
                            data-remove-class=\"closed; ##{@id}\">").html_safe
      end

      def drawer_id
        @id
      end

      def id
        @id
      end

      private
    end
  end
end
